translate.misc.selector.ByMethod

Package translate :: Package misc :: Module selector :: Class ByMethod |
[hide private]
[frames] | no frames]

# Class ByMethod

source code

Base class for dispatching to method named by REQUEST_METHOD.

Instance Methods | [hide private]
__call__(self, environ, start_response) Dispatch based on REQUEST_METHOD. | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Static Methods | [hide private]
_method_not_allowed(environ, start_response) Respond with a 405 and appropriate Allow header. | source code

Properties | [hide private]
Inherited from `object`: `__class__`